@@ -244,7 +244,7 @@
 *> \author Univ. of Colorado Denver
 *> \author NAG Ltd.
 *
-*> \ingroup hsein
+*> \ingroup realOTHERcomputational
 *
 *> \par Further Details:
 *  =====================
@@ -257,8 +257,7 @@
 *> \endverbatim
 *>
 *  =====================================================================
-      SUBROUTINE SHSEIN( SIDE, EIGSRC, INITV, SELECT, N, H, LDH, WR,
-     $                   WI,
+      SUBROUTINE SHSEIN( SIDE, EIGSRC, INITV, SELECT, N, H, LDH, WR, WI,
      $                   VL, LDVL, VR, LDVR, MM, M, WORK, IFAILL,
      $                   IFAILR, INFO )
 *
@@ -367,7 +366,7 @@
 *
       UNFL = SLAMCH( 'Safe minimum' )
       ULP = SLAMCH( 'Precision' )
-      SMLNUM = UNFL*( REAL( N ) / ULP )
+      SMLNUM = UNFL*( N / ULP )
       BIGNUM = ( ONE-ULP ) / SMLNUM
 *
       LDWORK = N + 1
@@ -458,8 +457,7 @@
 *
 *              Compute left eigenvector.
 *
-               CALL SLAEIN( .FALSE., NOINIT, N-KL+1, H( KL, KL ),
-     $                      LDH,
+               CALL SLAEIN( .FALSE., NOINIT, N-KL+1, H( KL, KL ), LDH,
      $                      WKR, WKI, VL( KL, KSR ), VL( KL, KSI ),
      $                      WORK, LDWORK, WORK( N*N+N+1 ), EPS3, SMLNUM,
      $                      BIGNUM, IINFO )
