@@ -52,10 +52,10 @@
 *>          Specifies whether the output from this procedure is used
 *>          to compute the matrix V:
 *>          = 'V': the product of the Jacobi rotations is accumulated
-*>                 by postmulyiplying the N-by-N array V.
+*>                 by postmultiplying the N-by-N array V.
 *>                (See the description of V.)
 *>          = 'A': the product of the Jacobi rotations is accumulated
-*>                 by postmulyiplying the MV-by-N array V.
+*>                 by postmultiplying the MV-by-N array V.
 *>                (See the descriptions of MV and V.)
 *>          = 'N': the Jacobi rotations are not accumulated.
 *> \endverbatim
@@ -117,7 +117,7 @@
 *> \param[in] MV
 *> \verbatim
 *>          MV is INTEGER
-*>          If JOBV = 'A', then MV rows of V are post-multipled by a
+*>          If JOBV = 'A', then MV rows of V are post-multiplied by a
 *>                           sequence of Jacobi rotations.
 *>          If JOBV = 'N',   then MV is not referenced.
 *> \endverbatim
@@ -125,9 +125,9 @@
 *> \param[in,out] V
 *> \verbatim
 *>          V is REAL array, dimension (LDV,N)
-*>          If JOBV = 'V' then N rows of V are post-multipled by a
+*>          If JOBV = 'V' then N rows of V are post-multiplied by a
 *>                           sequence of Jacobi rotations.
-*>          If JOBV = 'A' then MV rows of V are post-multipled by a
+*>          If JOBV = 'A' then MV rows of V are post-multiplied by a
 *>                           sequence of Jacobi rotations.
 *>          If JOBV = 'N',   then V is not referenced.
 *> \endverbatim
@@ -193,7 +193,7 @@
 *> \author Univ. of Colorado Denver
 *> \author NAG Ltd.
 *
-*> \ingroup realOTHERcomputational
+*> \ingroup gsvj0
 *
 *> \par Further Details:
 *  =====================
@@ -259,7 +259,8 @@
       EXTERNAL           ISAMAX, LSAME, SDOT, SNRM2
 *     ..
 *     .. External Subroutines ..
-      EXTERNAL           SAXPY, SCOPY, SLASCL, SLASSQ, SROTM, SSWAP,
+      EXTERNAL           SAXPY, SCOPY, SLASCL, SLASSQ, SROTM,
+     $                   SSWAP,
      $                   XERBLA
 *     ..
 *     .. Executable Statements ..
@@ -424,12 +425,15 @@
                            IF( AAQQ.GE.ONE ) THEN
                               ROTOK = ( SMALL*AAPP ).LE.AAQQ
                               IF( AAPP.LT.( BIG / AAQQ ) ) THEN
-                                 AAPQ = ( SDOT( M, A( 1, p ), 1, A( 1,
+                                 AAPQ = ( SDOT( M, A( 1, p ), 1,
+     $                                    A( 1,
      $                                  q ), 1 )*D( p )*D( q ) / AAQQ )
      $                                  / AAPP
                               ELSE
-                                 CALL SCOPY( M, A( 1, p ), 1, WORK, 1 )
-                                 CALL SLASCL( 'G', 0, 0, AAPP, D( p ),
+                                 CALL SCOPY( M, A( 1, p ), 1, WORK,
+     $                                       1 )
+                                 CALL SLASCL( 'G', 0, 0, AAPP,
+     $                                        D( p ),
      $                                        M, 1, WORK, LDA, IERR )
                                  AAPQ = SDOT( M, WORK, 1, A( 1, q ),
      $                                  1 )*D( q ) / AAQQ
@@ -437,12 +441,15 @@
                            ELSE
                               ROTOK = AAPP.LE.( AAQQ / SMALL )
                               IF( AAPP.GT.( SMALL / AAQQ ) ) THEN
-                                 AAPQ = ( SDOT( M, A( 1, p ), 1, A( 1,
+                                 AAPQ = ( SDOT( M, A( 1, p ), 1,
+     $                                    A( 1,
      $                                  q ), 1 )*D( p )*D( q ) / AAQQ )
      $                                  / AAPP
                               ELSE
-                                 CALL SCOPY( M, A( 1, q ), 1, WORK, 1 )
-                                 CALL SLASCL( 'G', 0, 0, AAQQ, D( q ),
+                                 CALL SCOPY( M, A( 1, q ), 1, WORK,
+     $                                       1 )
+                                 CALL SLASCL( 'G', 0, 0, AAQQ,
+     $                                        D( q ),
      $                                        M, 1, WORK, LDA, IERR )
                                  AAPQ = SDOT( M, WORK, 1, A( 1, p ),
      $                                  1 )*D( p ) / AAPP
@@ -511,7 +518,8 @@
                                           FASTR( 4 ) = -T*AQOAP
                                           D( p ) = D( p )*CS
                                           D( q ) = D( q )*CS
-                                          CALL SROTM( M, A( 1, p ), 1,
+                                          CALL SROTM( M, A( 1, p ),
+     $                                                1,
      $                                                A( 1, q ), 1,
      $                                                FASTR )
                                           IF( RSVEC )CALL SROTM( MVL,
@@ -527,7 +535,8 @@
                                           D( p ) = D( p )*CS
                                           D( q ) = D( q ) / CS
                                           IF( RSVEC ) THEN
-                                             CALL SAXPY( MVL, -T*AQOAP,
+                                             CALL SAXPY( MVL,
+     $                                                   -T*AQOAP,
      $                                                   V( 1, q ), 1,
      $                                                   V( 1, p ), 1 )
                                              CALL SAXPY( MVL,
@@ -541,13 +550,15 @@
                                           CALL SAXPY( M, T*APOAQ,
      $                                                A( 1, p ), 1,
      $                                                A( 1, q ), 1 )
-                                          CALL SAXPY( M, -CS*SN*AQOAP,
+                                          CALL SAXPY( M,
+     $                                                -CS*SN*AQOAP,
      $                                                A( 1, q ), 1,
      $                                                A( 1, p ), 1 )
                                           D( p ) = D( p ) / CS
                                           D( q ) = D( q )*CS
                                           IF( RSVEC ) THEN
-                                             CALL SAXPY( MVL, T*APOAQ,
+                                             CALL SAXPY( MVL,
+     $                                                   T*APOAQ,
      $                                                   V( 1, p ), 1,
      $                                                   V( 1, q ), 1 )
                                              CALL SAXPY( MVL,
@@ -560,7 +571,8 @@
                                              CALL SAXPY( M, -T*AQOAP,
      $                                                   A( 1, q ), 1,
      $                                                   A( 1, p ), 1 )
-                                             CALL SAXPY( M, CS*SN*APOAQ,
+                                             CALL SAXPY( M,
+     $                                                   CS*SN*APOAQ,
      $                                                   A( 1, p ), 1,
      $                                                   A( 1, q ), 1 )
                                              D( p ) = D( p )*CS
@@ -601,15 +613,19 @@
 *
                               ELSE
 *              .. have to use modified Gram-Schmidt like transformation
-                                 CALL SCOPY( M, A( 1, p ), 1, WORK, 1 )
-                                 CALL SLASCL( 'G', 0, 0, AAPP, ONE, M,
+                                 CALL SCOPY( M, A( 1, p ), 1, WORK,
+     $                                       1 )
+                                 CALL SLASCL( 'G', 0, 0, AAPP, ONE,
+     $                                        M,
      $                                        1, WORK, LDA, IERR )
-                                 CALL SLASCL( 'G', 0, 0, AAQQ, ONE, M,
+                                 CALL SLASCL( 'G', 0, 0, AAQQ, ONE,
+     $                                        M,
      $                                        1, A( 1, q ), LDA, IERR )
                                  TEMP1 = -AAPQ*D( p ) / D( q )
                                  CALL SAXPY( M, TEMP1, WORK, 1,
      $                                       A( 1, q ), 1 )
-                                 CALL SLASCL( 'G', 0, 0, ONE, AAQQ, M,
+                                 CALL SLASCL( 'G', 0, 0, ONE, AAQQ,
+     $                                        M,
      $                                        1, A( 1, q ), LDA, IERR )
                                  SVA( q ) = AAQQ*SQRT( MAX( ZERO,
      $                                      ONE-AAPQ*AAPQ ) )
@@ -623,7 +639,8 @@
      $                            THEN
                                  IF( ( AAQQ.LT.ROOTBIG ) .AND.
      $                               ( AAQQ.GT.ROOTSFMIN ) ) THEN
-                                    SVA( q ) = SNRM2( M, A( 1, q ), 1 )*
+                                    SVA( q ) = SNRM2( M, A( 1, q ),
+     $                                   1 )*
      $                                         D( q )
                                  ELSE
                                     T = ZERO
@@ -724,12 +741,15 @@
                                  ROTOK = ( SMALL*AAQQ ).LE.AAPP
                               END IF
                               IF( AAPP.LT.( BIG / AAQQ ) ) THEN
-                                 AAPQ = ( SDOT( M, A( 1, p ), 1, A( 1,
+                                 AAPQ = ( SDOT( M, A( 1, p ), 1,
+     $                                    A( 1,
      $                                  q ), 1 )*D( p )*D( q ) / AAQQ )
      $                                  / AAPP
                               ELSE
-                                 CALL SCOPY( M, A( 1, p ), 1, WORK, 1 )
-                                 CALL SLASCL( 'G', 0, 0, AAPP, D( p ),
+                                 CALL SCOPY( M, A( 1, p ), 1, WORK,
+     $                                       1 )
+                                 CALL SLASCL( 'G', 0, 0, AAPP,
+     $                                        D( p ),
      $                                        M, 1, WORK, LDA, IERR )
                                  AAPQ = SDOT( M, WORK, 1, A( 1, q ),
      $                                  1 )*D( q ) / AAQQ
@@ -741,12 +761,15 @@
                                  ROTOK = AAQQ.LE.( AAPP / SMALL )
                               END IF
                               IF( AAPP.GT.( SMALL / AAQQ ) ) THEN
-                                 AAPQ = ( SDOT( M, A( 1, p ), 1, A( 1,
+                                 AAPQ = ( SDOT( M, A( 1, p ), 1,
+     $                                    A( 1,
      $                                  q ), 1 )*D( p )*D( q ) / AAQQ )
      $                                  / AAPP
                               ELSE
-                                 CALL SCOPY( M, A( 1, q ), 1, WORK, 1 )
-                                 CALL SLASCL( 'G', 0, 0, AAQQ, D( q ),
+                                 CALL SCOPY( M, A( 1, q ), 1, WORK,
+     $                                       1 )
+                                 CALL SLASCL( 'G', 0, 0, AAQQ,
+     $                                        D( q ),
      $                                        M, 1, WORK, LDA, IERR )
                                  AAPQ = SDOT( M, WORK, 1, A( 1, p ),
      $                                  1 )*D( p ) / AAPP
@@ -810,7 +833,8 @@
                                           FASTR( 4 ) = -T*AQOAP
                                           D( p ) = D( p )*CS
                                           D( q ) = D( q )*CS
-                                          CALL SROTM( M, A( 1, p ), 1,
+                                          CALL SROTM( M, A( 1, p ),
+     $                                                1,
      $                                                A( 1, q ), 1,
      $                                                FASTR )
                                           IF( RSVEC )CALL SROTM( MVL,
@@ -824,7 +848,8 @@
      $                                                A( 1, p ), 1,
      $                                                A( 1, q ), 1 )
                                           IF( RSVEC ) THEN
-                                             CALL SAXPY( MVL, -T*AQOAP,
+                                             CALL SAXPY( MVL,
+     $                                                   -T*AQOAP,
      $                                                   V( 1, q ), 1,
      $                                                   V( 1, p ), 1 )
                                              CALL SAXPY( MVL,
@@ -840,11 +865,13 @@
                                           CALL SAXPY( M, T*APOAQ,
      $                                                A( 1, p ), 1,
      $                                                A( 1, q ), 1 )
-                                          CALL SAXPY( M, -CS*SN*AQOAP,
+                                          CALL SAXPY( M,
+     $                                                -CS*SN*AQOAP,
      $                                                A( 1, q ), 1,
      $                                                A( 1, p ), 1 )
                                           IF( RSVEC ) THEN
-                                             CALL SAXPY( MVL, T*APOAQ,
+                                             CALL SAXPY( MVL,
+     $                                                   T*APOAQ,
      $                                                   V( 1, p ), 1,
      $                                                   V( 1, q ), 1 )
                                              CALL SAXPY( MVL,
@@ -859,7 +886,8 @@
                                              CALL SAXPY( M, -T*AQOAP,
      $                                                   A( 1, q ), 1,
      $                                                   A( 1, p ), 1 )
-                                             CALL SAXPY( M, CS*SN*APOAQ,
+                                             CALL SAXPY( M,
+     $                                                   CS*SN*APOAQ,
      $                                                   A( 1, p ), 1,
      $                                                   A( 1, q ), 1 )
                                              D( p ) = D( p )*CS
@@ -900,34 +928,42 @@
 *
                               ELSE
                                  IF( AAPP.GT.AAQQ ) THEN
-                                    CALL SCOPY( M, A( 1, p ), 1, WORK,
+                                    CALL SCOPY( M, A( 1, p ), 1,
+     $                                          WORK,
      $                                          1 )
-                                    CALL SLASCL( 'G', 0, 0, AAPP, ONE,
+                                    CALL SLASCL( 'G', 0, 0, AAPP,
+     $                                           ONE,
      $                                           M, 1, WORK, LDA, IERR )
-                                    CALL SLASCL( 'G', 0, 0, AAQQ, ONE,
+                                    CALL SLASCL( 'G', 0, 0, AAQQ,
+     $                                           ONE,
      $                                           M, 1, A( 1, q ), LDA,
      $                                           IERR )
                                     TEMP1 = -AAPQ*D( p ) / D( q )
                                     CALL SAXPY( M, TEMP1, WORK, 1,
      $                                          A( 1, q ), 1 )
-                                    CALL SLASCL( 'G', 0, 0, ONE, AAQQ,
+                                    CALL SLASCL( 'G', 0, 0, ONE,
+     $                                           AAQQ,
      $                                           M, 1, A( 1, q ), LDA,
      $                                           IERR )
                                     SVA( q ) = AAQQ*SQRT( MAX( ZERO,
      $                                         ONE-AAPQ*AAPQ ) )
                                     MXSINJ = MAX( MXSINJ, SFMIN )
                                  ELSE
-                                    CALL SCOPY( M, A( 1, q ), 1, WORK,
+                                    CALL SCOPY( M, A( 1, q ), 1,
+     $                                          WORK,
      $                                          1 )
-                                    CALL SLASCL( 'G', 0, 0, AAQQ, ONE,
+                                    CALL SLASCL( 'G', 0, 0, AAQQ,
+     $                                           ONE,
      $                                           M, 1, WORK, LDA, IERR )
-                                    CALL SLASCL( 'G', 0, 0, AAPP, ONE,
+                                    CALL SLASCL( 'G', 0, 0, AAPP,
+     $                                           ONE,
      $                                           M, 1, A( 1, p ), LDA,
      $                                           IERR )
                                     TEMP1 = -AAPQ*D( q ) / D( p )
                                     CALL SAXPY( M, TEMP1, WORK, 1,
      $                                          A( 1, p ), 1 )
-                                    CALL SLASCL( 'G', 0, 0, ONE, AAPP,
+                                    CALL SLASCL( 'G', 0, 0, ONE,
+     $                                           AAPP,
      $                                           M, 1, A( 1, p ), LDA,
      $                                           IERR )
                                     SVA( p ) = AAPP*SQRT( MAX( ZERO,
@@ -943,7 +979,8 @@
      $                            THEN
                                  IF( ( AAQQ.LT.ROOTBIG ) .AND.
      $                               ( AAQQ.GT.ROOTSFMIN ) ) THEN
-                                    SVA( q ) = SNRM2( M, A( 1, q ), 1 )*
+                                    SVA( q ) = SNRM2( M, A( 1, q ),
+     $                                   1 )*
      $                                         D( q )
                                  ELSE
                                     T = ZERO
