@@ -21,7 +21,7 @@
 *       SUBROUTINE DLASYF_ROOK( UPLO, N, NB, KB, A, LDA, IPIV, W, LDW, INFO )
 *
 *       .. Scalar Arguments ..
-*       CHARACTER          UPLO
+*       CHARADLATER          UPLO
 *       INTEGER            INFO, KB, LDA, LDW, N, NB
 *       ..
 *       .. Array Arguments ..
@@ -161,7 +161,9 @@
 *> \author Univ. of Colorado Denver
 *> \author NAG Ltd.
 *
-*> \ingroup lahef_rook
+*> \date November 2013
+*
+*> \ingroup doubleSYcomputational
 *
 *> \par Contributors:
 *  ==================
@@ -182,9 +184,10 @@
       SUBROUTINE DLASYF_ROOK( UPLO, N, NB, KB, A, LDA, IPIV, W, LDW,
      $                        INFO )
 *
-*  -- LAPACK computational routine --
+*  -- LAPACK computational routine (version 3.5.0) --
 *  -- LAPACK is a software package provided by Univ. of Tennessee,    --
 *  -- Univ. of California Berkeley, Univ. of Colorado Denver and NAG Ltd..--
+*     November 2013
 *
 *     .. Scalar Arguments ..
       CHARACTER          UPLO
@@ -205,7 +208,7 @@
 *     ..
 *     .. Local Scalars ..
       LOGICAL            DONE
-      INTEGER            IMAX, ITEMP, J, JJ, JMAX, JP1, JP2, K, KK,
+      INTEGER            IMAX, ITEMP, J, JB, JJ, JMAX, JP1, JP2, K, KK,
      $                   KW, KKW, KP, KSTEP, P, II
 
       DOUBLE PRECISION   ABSAKK, ALPHA, COLMAX, D11, D12, D21, D22,
@@ -218,7 +221,7 @@
       EXTERNAL           LSAME, IDAMAX, DLAMCH
 *     ..
 *     .. External Subroutines ..
-      EXTERNAL           DCOPY, DGEMMTR, DGEMV, DSCAL, DSWAP
+      EXTERNAL           DCOPY, DGEMM, DGEMV, DSCAL, DSWAP
 *     ..
 *     .. Intrinsic Functions ..
       INTRINSIC          ABS, MAX, MIN, SQRT
@@ -317,8 +320,7 @@
 *
 *                 Copy column IMAX to column KW-1 of W and update it
 *
-                  CALL DCOPY( IMAX, A( 1, IMAX ), 1, W( 1, KW-1 ),
-     $                        1 )
+                  CALL DCOPY( IMAX, A( 1, IMAX ), 1, W( 1, KW-1 ), 1 )
                   CALL DCOPY( K-IMAX, A( IMAX, IMAX+1 ), LDA,
      $                        W( IMAX+1, KW-1 ), 1 )
 *
@@ -417,8 +419,7 @@
 *              and last N-K+2 columns of W
 *
                CALL DSWAP( N-K+1, A( K, K ), LDA, A( P, K ), LDA )
-               CALL DSWAP( N-KK+1, W( K, KKW ), LDW, W( P, KKW ),
-     $                     LDW )
+               CALL DSWAP( N-KK+1, W( K, KKW ), LDW, W( P, KKW ), LDW )
             END IF
 *
 *           Updated column KP is already stored in column KKW of W
@@ -435,8 +436,7 @@
 *              Interchange rows KK and KP in last N-KK+1 columns
 *              of A and W
 *
-               CALL DSWAP( N-KK+1, A( KK, KK ), LDA, A( KP, KK ),
-     $                     LDA )
+               CALL DSWAP( N-KK+1, A( KK, KK ), LDA, A( KP, KK ), LDA )
                CALL DSWAP( N-KK+1, W( KK, KKW ), LDW, W( KP, KKW ),
      $                     LDW )
             END IF
@@ -517,9 +517,26 @@
 *
 *        A11 := A11 - U12*D*U12**T = A11 - U12*W**T
 *
-         CALL DGEMMTR( 'Upper', 'No transpose', 'Transpose', K, N-K,
-     $                 -ONE, A( 1, K+1 ), LDA, W( 1, KW+1 ), LDW,
-     $                 ONE, A( 1, 1 ), LDA )
+*        computing blocks of NB columns at a time
+*
+         DO 50 J = ( ( K-1 ) / NB )*NB + 1, 1, -NB
+            JB = MIN( NB, K-J+1 )
+*
+*           Update the upper triangle of the diagonal block
+*
+            DO 40 JJ = J, J + JB - 1
+               CALL DGEMV( 'No transpose', JJ-J+1, N-K, -ONE,
+     $                     A( J, K+1 ), LDA, W( JJ, KW+1 ), LDW, ONE,
+     $                     A( J, JJ ), 1 )
+   40       CONTINUE
+*
+*           Update the rectangular superdiagonal block
+*
+            IF( J.GE.2 )
+     $         CALL DGEMM( 'No transpose', 'Transpose', J-1, JB,
+     $                  N-K, -ONE, A( 1, K+1 ), LDA, W( J, KW+1 ), LDW,
+     $                  ONE, A( 1, J ), LDA )
+   50    CONTINUE
 *
 *        Put U12 in standard form by partially undoing the interchanges
 *        in columns k+1:n
@@ -629,8 +646,7 @@
 *
 *                 Copy column IMAX to column K+1 of W and update it
 *
-                  CALL DCOPY( IMAX-K, A( IMAX, K ), LDA, W( K, K+1 ),
-     $                        1)
+                  CALL DCOPY( IMAX-K, A( IMAX, K ), LDA, W( K, K+1 ), 1)
                   CALL DCOPY( N-IMAX+1, A( IMAX, IMAX ), 1,
      $                        W( IMAX, K+1 ), 1 )
                   IF( K.GT.1 )
@@ -650,8 +666,7 @@
                   END IF
 *
                   IF( IMAX.LT.N ) THEN
-                     ITEMP = IMAX + IDAMAX( N-IMAX, W( IMAX+1, K+1 ),
-     $                                      1)
+                     ITEMP = IMAX + IDAMAX( N-IMAX, W( IMAX+1, K+1 ), 1)
                      DTEMP = ABS( W( ITEMP, K+1 ) )
                      IF( DTEMP.GT.ROWMAX ) THEN
                         ROWMAX = DTEMP
@@ -673,8 +688,7 @@
 *
 *                    copy column K+1 of W to column K of W
 *
-                     CALL DCOPY( N-K+1, W( K, K+1 ), 1, W( K, K ),
-     $                           1 )
+                     CALL DCOPY( N-K+1, W( K, K+1 ), 1, W( K, K ), 1 )
 *
                      DONE = .TRUE.
 *
@@ -700,8 +714,7 @@
 *
 *                    Copy updated JMAXth (next IMAXth) column to Kth of W
 *
-                     CALL DCOPY( N-K+1, W( K, K+1 ), 1, W( K, K ),
-     $                           1 )
+                     CALL DCOPY( N-K+1, W( K, K+1 ), 1, W( K, K ), 1 )
 *
                   END IF
 *
@@ -736,8 +749,7 @@
 *              Copy non-updated column KK to column KP
 *
                A( KP, K ) = A( KK, K )
-               CALL DCOPY( KP-K-1, A( K+1, KK ), 1, A( KP, K+1 ),
-     $                     LDA )
+               CALL DCOPY( KP-K-1, A( K+1, KK ), 1, A( KP, K+1 ), LDA )
                CALL DCOPY( N-KP+1, A( KP, KK ), 1, A( KP, KP ), 1 )
 *
 *              Interchange rows KK and KP in first KK columns of A and W
@@ -821,9 +833,26 @@
 *
 *        A22 := A22 - L21*D*L21**T = A22 - L21*W**T
 *
-         CALL DGEMMTR( 'Lower', 'No transpose', 'Transpose', N-K+1,
-     $                 K-1, -ONE, A( K, 1 ), LDA, W( K, 1 ), LDW,
-     $                 ONE, A( K, K ), LDA )
+*        computing blocks of NB columns at a time
+*
+         DO 110 J = K, N, NB
+            JB = MIN( NB, N-J+1 )
+*
+*           Update the lower triangle of the diagonal block
+*
+            DO 100 JJ = J, J + JB - 1
+               CALL DGEMV( 'No transpose', J+JB-JJ, K-1, -ONE,
+     $                     A( JJ, 1 ), LDA, W( JJ, 1 ), LDW, ONE,
+     $                     A( JJ, JJ ), 1 )
+  100       CONTINUE
+*
+*           Update the rectangular subdiagonal block
+*
+            IF( J+JB.LE.N )
+     $         CALL DGEMM( 'No transpose', 'Transpose', N-J-JB+1, JB,
+     $                     K-1, -ONE, A( J+JB, 1 ), LDA, W( J, 1 ), LDW,
+     $                     ONE, A( J+JB, J ), LDA )
+  110    CONTINUE
 *
 *        Put L21 in standard form by partially undoing the interchanges
 *        in columns 1:k-1
