@@ -208,6 +208,8 @@
 *> \author Univ. of Colorado Denver
 *> \author NAG Ltd.
 *
+*> \date January 2015
+*
 *> \ingroup complex16OTHERcomputational
 *
 *> \par Further Details:
@@ -215,7 +217,7 @@
 *>
 *> \verbatim
 *>
-*>  This routine reduces A to Hessenberg form and maintains B in triangular form
+*>  This routine reduces A to Hessenberg form and maintains B in
 *>  using a blocked variant of Moler and Stewart's original algorithm,
 *>  as described by Kagstrom, Kressner, Quintana-Orti, and Quintana-Orti
 *>  (BIT 2008).
@@ -225,9 +227,10 @@
       SUBROUTINE ZGGHD3( COMPQ, COMPZ, N, ILO, IHI, A, LDA, B, LDB, Q,
      $                   LDQ, Z, LDZ, WORK, LWORK, INFO )
 *
-*  -- LAPACK computational routine --
+*  -- LAPACK computational routine (version 3.6.1) --
 *  -- LAPACK is a software package provided by Univ. of Tennessee,    --
 *  -- Univ. of California Berkeley, Univ. of Colorado Denver and NAG Ltd..--
+*     January 2015
 *
       IMPLICIT NONE
 *
@@ -263,8 +266,7 @@
       EXTERNAL           ILAENV, LSAME
 *     ..
 *     .. External Subroutines ..
-      EXTERNAL           ZGGHRD, ZLARTG, ZLASET, ZUNM22, ZROT, ZGEMM,
-     $                   ZGEMV, ZTRMV, ZLACPY, XERBLA
+      EXTERNAL           ZGGHRD, ZLARTG, ZLASET, ZUNM22, ZROT, XERBLA
 *     ..
 *     .. Intrinsic Functions ..
       INTRINSIC          DBLE, DCMPLX, DCONJG, MAX
