@@ -32,25 +32,25 @@
 
 #include "lapacke_utils.h"
 
-lapack_int API_SUFFIX(LAPACKE_zhegst)( int matrix_layout, lapack_int itype, char uplo,
+lapack_int LAPACKE_zhegst( int matrix_layout, lapack_int itype, char uplo,
                            lapack_int n, lapack_complex_double* a,
-                           lapack_int lda, const lapack_complex_double* b,
+                           lapack_int lda, lapack_complex_double* b,
                            lapack_int ldb )
 {
     if( matrix_layout != LAPACK_COL_MAJOR && matrix_layout != LAPACK_ROW_MAJOR ) {
-        API_SUFFIX(LAPACKE_xerbla)( "LAPACKE_zhegst", -1 );
+        LAPACKE_xerbla( "LAPACKE_zhegst", -1 );
         return -1;
     }
 #ifndef LAPACK_DISABLE_NAN_CHECK
     if( LAPACKE_get_nancheck() ) {
         /* Optionally check input matrices for NaNs */
-        if( API_SUFFIX(LAPACKE_zhe_nancheck)( matrix_layout, uplo, n, a, lda ) ) {
+        if( LAPACKE_zhe_nancheck( matrix_layout, uplo, n, a, lda ) ) {
             return -5;
         }
-        if( API_SUFFIX(LAPACKE_zhe_nancheck)( matrix_layout, uplo, n, b, ldb ) ) {
+        if( LAPACKE_zge_nancheck( matrix_layout, n, n, b, ldb ) ) {
             return -7;
         }
     }
 #endif
-    return API_SUFFIX(LAPACKE_zhegst_work)( matrix_layout, itype, uplo, n, a, lda, b, ldb );
+    return LAPACKE_zhegst_work( matrix_layout, itype, uplo, n, a, lda, b, ldb );
 }
