@@ -25,8 +25,8 @@
 #include <complex.h>
 
 #define FLEXIBLAS_LAPACK_MAJOR 3
-#define FLEXIBLAS_LAPACK_MINOR 9
-#define FLEXIBLAS_LAPACK_PATCH 1
+#define FLEXIBLAS_LAPACK_MINOR 11
+#define FLEXIBLAS_LAPACK_PATCH 0
 #define FLEXIBLAS_LAPACK_EXTRA without deprecated
 
 
@@ -73,6 +73,7 @@ typedef struct _flexiblas_lapack_backend {
     flexiblas_blasfn cgels;
     flexiblas_blasfn cgelsd;
     flexiblas_blasfn cgelss;
+    flexiblas_blasfn cgelst;
     flexiblas_blasfn cgelsy;
     flexiblas_blasfn cgemlq;
     flexiblas_blasfn cgemlqt;
@@ -280,6 +281,10 @@ typedef struct _flexiblas_lapack_backend {
     flexiblas_blasfn claqsb;
     flexiblas_blasfn claqsp;
     flexiblas_blasfn claqsy;
+    flexiblas_blasfn claqz0;
+    flexiblas_blasfn claqz1;
+    flexiblas_blasfn claqz2;
+    flexiblas_blasfn claqz3;
     flexiblas_blasfn clar1v;
     flexiblas_blasfn clar2v;
     flexiblas_blasfn clarcm;
@@ -314,6 +319,7 @@ typedef struct _flexiblas_lapack_backend {
     flexiblas_blasfn clatps;
     flexiblas_blasfn clatrd;
     flexiblas_blasfn clatrs;
+    flexiblas_blasfn clatrs3;
     flexiblas_blasfn clatrz;
     flexiblas_blasfn clatsqr;
     flexiblas_blasfn claunhr_col_getrfnp;
@@ -450,6 +456,7 @@ typedef struct _flexiblas_lapack_backend {
     flexiblas_blasfn ctrsen;
     flexiblas_blasfn ctrsna;
     flexiblas_blasfn ctrsyl;
+    flexiblas_blasfn ctrsyl3;
     flexiblas_blasfn ctrti2;
     flexiblas_blasfn ctrtri;
     flexiblas_blasfn ctrtrs;
@@ -499,7 +506,6 @@ typedef struct _flexiblas_lapack_backend {
     flexiblas_blasfn dbdsdc;
     flexiblas_blasfn dbdsqr;
     flexiblas_blasfn dbdsvdx;
-    flexiblas_blasfn dcombssq;
     flexiblas_blasfn ddisna;
     flexiblas_blasfn dgbbrd;
     flexiblas_blasfn dgbcon;
@@ -533,6 +539,7 @@ typedef struct _flexiblas_lapack_backend {
     flexiblas_blasfn dgels;
     flexiblas_blasfn dgelsd;
     flexiblas_blasfn dgelss;
+    flexiblas_blasfn dgelst;
     flexiblas_blasfn dgelsy;
     flexiblas_blasfn dgemlq;
     flexiblas_blasfn dgemlqt;
@@ -676,6 +683,11 @@ typedef struct _flexiblas_lapack_backend {
     flexiblas_blasfn dlaqsp;
     flexiblas_blasfn dlaqsy;
     flexiblas_blasfn dlaqtr;
+    flexiblas_blasfn dlaqz0;
+    flexiblas_blasfn dlaqz1;
+    flexiblas_blasfn dlaqz2;
+    flexiblas_blasfn dlaqz3;
+    flexiblas_blasfn dlaqz4;
     flexiblas_blasfn dlar1v;
     flexiblas_blasfn dlar2v;
     flexiblas_blasfn dlarf;
@@ -687,6 +699,7 @@ typedef struct _flexiblas_lapack_backend {
     flexiblas_blasfn dlarfx;
     flexiblas_blasfn dlarfy;
     flexiblas_blasfn dlargv;
+    flexiblas_blasfn dlarmm;
     flexiblas_blasfn dlarnv;
     flexiblas_blasfn dlarra;
     flexiblas_blasfn dlarrb;
@@ -744,6 +757,7 @@ typedef struct _flexiblas_lapack_backend {
     flexiblas_blasfn dlatps;
     flexiblas_blasfn dlatrd;
     flexiblas_blasfn dlatrs;
+    flexiblas_blasfn dlatrs3;
     flexiblas_blasfn dlatrz;
     flexiblas_blasfn dlatsqr;
     flexiblas_blasfn dlauu2;
@@ -828,6 +842,7 @@ typedef struct _flexiblas_lapack_backend {
     flexiblas_blasfn dpttrf;
     flexiblas_blasfn dpttrs;
     flexiblas_blasfn dptts2;
+    flexiblas_blasfn droundup_lwork;
     flexiblas_blasfn drscl;
     flexiblas_blasfn dsb2st_kernels;
     flexiblas_blasfn dsbev;
@@ -961,6 +976,7 @@ typedef struct _flexiblas_lapack_backend {
     flexiblas_blasfn dtrsen;
     flexiblas_blasfn dtrsna;
     flexiblas_blasfn dtrsyl;
+    flexiblas_blasfn dtrsyl3;
     flexiblas_blasfn dtrti2;
     flexiblas_blasfn dtrtri;
     flexiblas_blasfn dtrtrs;
@@ -991,7 +1007,6 @@ typedef struct _flexiblas_lapack_backend {
     flexiblas_blasfn sbdsdc;
     flexiblas_blasfn sbdsqr;
     flexiblas_blasfn sbdsvdx;
-    flexiblas_blasfn scombssq;
     flexiblas_blasfn scsum1;
     flexiblas_blasfn sdisna;
     flexiblas_blasfn second;
@@ -1027,6 +1042,7 @@ typedef struct _flexiblas_lapack_backend {
     flexiblas_blasfn sgels;
     flexiblas_blasfn sgelsd;
     flexiblas_blasfn sgelss;
+    flexiblas_blasfn sgelst;
     flexiblas_blasfn sgelsy;
     flexiblas_blasfn sgemlq;
     flexiblas_blasfn sgemlqt;
@@ -1170,6 +1186,11 @@ typedef struct _flexiblas_lapack_backend {
     flexiblas_blasfn slaqsp;
     flexiblas_blasfn slaqsy;
     flexiblas_blasfn slaqtr;
+    flexiblas_blasfn slaqz0;
+    flexiblas_blasfn slaqz1;
+    flexiblas_blasfn slaqz2;
+    flexiblas_blasfn slaqz3;
+    flexiblas_blasfn slaqz4;
     flexiblas_blasfn slar1v;
     flexiblas_blasfn slar2v;
     flexiblas_blasfn slarf;
@@ -1181,6 +1202,7 @@ typedef struct _flexiblas_lapack_backend {
     flexiblas_blasfn slarfx;
     flexiblas_blasfn slarfy;
     flexiblas_blasfn slargv;
+    flexiblas_blasfn slarmm;
     flexiblas_blasfn slarnv;
     flexiblas_blasfn slarra;
     flexiblas_blasfn slarrb;
@@ -1237,6 +1259,7 @@ typedef struct _flexiblas_lapack_backend {
     flexiblas_blasfn slatps;
     flexiblas_blasfn slatrd;
     flexiblas_blasfn slatrs;
+    flexiblas_blasfn slatrs3;
     flexiblas_blasfn slatrz;
     flexiblas_blasfn slatsqr;
     flexiblas_blasfn slauu2;
@@ -1321,6 +1344,7 @@ typedef struct _flexiblas_lapack_backend {
     flexiblas_blasfn spttrf;
     flexiblas_blasfn spttrs;
     flexiblas_blasfn sptts2;
+    flexiblas_blasfn sroundup_lwork;
     flexiblas_blasfn srscl;
     flexiblas_blasfn ssb2st_kernels;
     flexiblas_blasfn ssbev;
@@ -1451,6 +1475,7 @@ typedef struct _flexiblas_lapack_backend {
     flexiblas_blasfn strsen;
     flexiblas_blasfn strsna;
     flexiblas_blasfn strsyl;
+    flexiblas_blasfn strsyl3;
     flexiblas_blasfn strti2;
     flexiblas_blasfn strtri;
     flexiblas_blasfn strtrs;
@@ -1494,6 +1519,7 @@ typedef struct _flexiblas_lapack_backend {
     flexiblas_blasfn zgels;
     flexiblas_blasfn zgelsd;
     flexiblas_blasfn zgelss;
+    flexiblas_blasfn zgelst;
     flexiblas_blasfn zgelsy;
     flexiblas_blasfn zgemlq;
     flexiblas_blasfn zgemlqt;
@@ -1700,6 +1726,10 @@ typedef struct _flexiblas_lapack_backend {
     flexiblas_blasfn zlaqsb;
     flexiblas_blasfn zlaqsp;
     flexiblas_blasfn zlaqsy;
+    flexiblas_blasfn zlaqz0;
+    flexiblas_blasfn zlaqz1;
+    flexiblas_blasfn zlaqz2;
+    flexiblas_blasfn zlaqz3;
     flexiblas_blasfn zlar1v;
     flexiblas_blasfn zlar2v;
     flexiblas_blasfn zlarcm;
@@ -1735,6 +1765,7 @@ typedef struct _flexiblas_lapack_backend {
     flexiblas_blasfn zlatps;
     flexiblas_blasfn zlatrd;
     flexiblas_blasfn zlatrs;
+    flexiblas_blasfn zlatrs3;
     flexiblas_blasfn zlatrz;
     flexiblas_blasfn zlatsqr;
     flexiblas_blasfn zlaunhr_col_getrfnp;
@@ -1870,6 +1901,7 @@ typedef struct _flexiblas_lapack_backend {
     flexiblas_blasfn ztrsen;
     flexiblas_blasfn ztrsna;
     flexiblas_blasfn ztrsyl;
+    flexiblas_blasfn ztrsyl3;
     flexiblas_blasfn ztrti2;
     flexiblas_blasfn ztrtri;
     flexiblas_blasfn ztrtrs;
