@@ -25,8 +25,8 @@
 #include <complex.h>
 
 #define FLEXIBLAS_LAPACK_MAJOR 3
-#define FLEXIBLAS_LAPACK_MINOR 12
-#define FLEXIBLAS_LAPACK_PATCH 1
+#define FLEXIBLAS_LAPACK_MINOR 10
+#define FLEXIBLAS_LAPACK_PATCH 0
 
 
 #ifdef __cplusplus
@@ -68,8 +68,6 @@ typedef struct _flexiblas_lapacke_backend {
     void *LAPACKE_cgebrd_work;
     void *LAPACKE_cgecon;
     void *LAPACKE_cgecon_work;
-    void *LAPACKE_cgedmd_work;
-    void *LAPACKE_cgedmdq_work;
     void *LAPACKE_cgeequ;
     void *LAPACKE_cgeequ_work;
     void *LAPACKE_cgeequb;
@@ -356,8 +354,6 @@ typedef struct _flexiblas_lapacke_backend {
     void *LAPACKE_clacrm_work;
     void *LAPACKE_clag2z;
     void *LAPACKE_clag2z_work;
-    void *LAPACKE_clangb;
-    void *LAPACKE_clangb_work;
     void *LAPACKE_clange;
     void *LAPACKE_clange_work;
     void *LAPACKE_clanhe;
@@ -605,7 +601,6 @@ typedef struct _flexiblas_lapacke_backend {
     void *LAPACKE_ctrsna;
     void *LAPACKE_ctrsna_work;
     void *LAPACKE_ctrsyl;
-    void *LAPACKE_ctrsyl3_work;
     void *LAPACKE_ctrsyl_work;
     void *LAPACKE_ctrtri;
     void *LAPACKE_ctrtri_work;
@@ -639,8 +634,6 @@ typedef struct _flexiblas_lapacke_backend {
     void *LAPACKE_cungtr_work;
     void *LAPACKE_cungtsqr_row;
     void *LAPACKE_cungtsqr_row_work;
-    void *LAPACKE_cunhr_col;
-    void *LAPACKE_cunhr_col_work;
     void *LAPACKE_cunmbr;
     void *LAPACKE_cunmbr_work;
     void *LAPACKE_cunmhr;
@@ -697,8 +690,6 @@ typedef struct _flexiblas_lapacke_backend {
     void *LAPACKE_dgebrd_work;
     void *LAPACKE_dgecon;
     void *LAPACKE_dgecon_work;
-    void *LAPACKE_dgedmd_work;
-    void *LAPACKE_dgedmdq_work;
     void *LAPACKE_dgeequ;
     void *LAPACKE_dgeequ_work;
     void *LAPACKE_dgeequb;
@@ -849,8 +840,6 @@ typedef struct _flexiblas_lapacke_backend {
     void *LAPACKE_dlag2s_work;
     void *LAPACKE_dlamch;
     void *LAPACKE_dlamch_work;
-    void *LAPACKE_dlangb;
-    void *LAPACKE_dlangb_work;
     void *LAPACKE_dlange;
     void *LAPACKE_dlange_work;
     void *LAPACKE_dlansy;
@@ -917,8 +906,6 @@ typedef struct _flexiblas_lapacke_backend {
     void *LAPACKE_dorgtr_work;
     void *LAPACKE_dorgtsqr_row;
     void *LAPACKE_dorgtsqr_row_work;
-    void *LAPACKE_dorhr_col;
-    void *LAPACKE_dorhr_col_work;
     void *LAPACKE_dormbr;
     void *LAPACKE_dormbr_work;
     void *LAPACKE_dormhr;
@@ -1230,8 +1217,6 @@ typedef struct _flexiblas_lapacke_backend {
     void *LAPACKE_dtrsna;
     void *LAPACKE_dtrsna_work;
     void *LAPACKE_dtrsyl;
-    void *LAPACKE_dtrsyl3;
-    void *LAPACKE_dtrsyl3_work;
     void *LAPACKE_dtrsyl_work;
     void *LAPACKE_dtrtri;
     void *LAPACKE_dtrtri_work;
@@ -1282,8 +1267,6 @@ typedef struct _flexiblas_lapacke_backend {
     void *LAPACKE_sgebrd_work;
     void *LAPACKE_sgecon;
     void *LAPACKE_sgecon_work;
-    void *LAPACKE_sgedmd_work;
-    void *LAPACKE_sgedmdq_work;
     void *LAPACKE_sgeequ;
     void *LAPACKE_sgeequ_work;
     void *LAPACKE_sgeequb;
@@ -1434,8 +1417,6 @@ typedef struct _flexiblas_lapacke_backend {
     void *LAPACKE_slag2d_work;
     void *LAPACKE_slamch;
     void *LAPACKE_slamch_work;
-    void *LAPACKE_slangb;
-    void *LAPACKE_slangb_work;
     void *LAPACKE_slange;
     void *LAPACKE_slange_work;
     void *LAPACKE_slansy;
@@ -1502,8 +1483,6 @@ typedef struct _flexiblas_lapacke_backend {
     void *LAPACKE_sorgtr_work;
     void *LAPACKE_sorgtsqr_row;
     void *LAPACKE_sorgtsqr_row_work;
-    void *LAPACKE_sorhr_col;
-    void *LAPACKE_sorhr_col_work;
     void *LAPACKE_sormbr;
     void *LAPACKE_sormbr_work;
     void *LAPACKE_sormhr;
@@ -1811,8 +1790,6 @@ typedef struct _flexiblas_lapacke_backend {
     void *LAPACKE_strsna;
     void *LAPACKE_strsna_work;
     void *LAPACKE_strsyl;
-    void *LAPACKE_strsyl3;
-    void *LAPACKE_strsyl3_work;
     void *LAPACKE_strsyl_work;
     void *LAPACKE_strtri;
     void *LAPACKE_strtri_work;
@@ -1858,8 +1835,6 @@ typedef struct _flexiblas_lapacke_backend {
     void *LAPACKE_zgebrd_work;
     void *LAPACKE_zgecon;
     void *LAPACKE_zgecon_work;
-    void *LAPACKE_zgedmd_work;
-    void *LAPACKE_zgedmdq_work;
     void *LAPACKE_zgeequ;
     void *LAPACKE_zgeequ_work;
     void *LAPACKE_zgeequb;
@@ -2146,8 +2121,6 @@ typedef struct _flexiblas_lapacke_backend {
     void *LAPACKE_zlacrm_work;
     void *LAPACKE_zlag2c;
     void *LAPACKE_zlag2c_work;
-    void *LAPACKE_zlangb;
-    void *LAPACKE_zlangb_work;
     void *LAPACKE_zlange;
     void *LAPACKE_zlange_work;
     void *LAPACKE_zlanhe;
@@ -2395,8 +2368,6 @@ typedef struct _flexiblas_lapacke_backend {
     void *LAPACKE_ztrsna;
     void *LAPACKE_ztrsna_work;
     void *LAPACKE_ztrsyl;
-    void *LAPACKE_ztrsyl3;
-    void *LAPACKE_ztrsyl3_work;
     void *LAPACKE_ztrsyl_work;
     void *LAPACKE_ztrtri;
     void *LAPACKE_ztrtri_work;
@@ -2430,8 +2401,6 @@ typedef struct _flexiblas_lapacke_backend {
     void *LAPACKE_zungtr_work;
     void *LAPACKE_zungtsqr_row;
     void *LAPACKE_zungtsqr_row_work;
-    void *LAPACKE_zunhr_col;
-    void *LAPACKE_zunhr_col_work;
     void *LAPACKE_zunmbr;
     void *LAPACKE_zunmbr_work;
     void *LAPACKE_zunmhr;
