@@ -25,7 +25,7 @@
 #include <complex.h>
 
 #define FLEXIBLAS_LAPACK_MAJOR 3
-#define FLEXIBLAS_LAPACK_MINOR 9
+#define FLEXIBLAS_LAPACK_MINOR 11
 #define FLEXIBLAS_LAPACK_PATCH 0
 
 
@@ -154,6 +154,8 @@ typedef struct _flexiblas_lapacke_backend {
     void *LAPACKE_cgetrs_work;
     void *LAPACKE_cgetsls;
     void *LAPACKE_cgetsls_work;
+    void *LAPACKE_cgetsqrhrt;
+    void *LAPACKE_cgetsqrhrt_work;
     void *LAPACKE_cggbak;
     void *LAPACKE_cggbak_work;
     void *LAPACKE_cggbal;
@@ -352,6 +354,8 @@ typedef struct _flexiblas_lapacke_backend {
     void *LAPACKE_clacrm_work;
     void *LAPACKE_clag2z;
     void *LAPACKE_clag2z_work;
+    void *LAPACKE_clangb;
+    void *LAPACKE_clangb_work;
     void *LAPACKE_clange;
     void *LAPACKE_clange_work;
     void *LAPACKE_clanhe;
@@ -599,6 +603,7 @@ typedef struct _flexiblas_lapacke_backend {
     void *LAPACKE_ctrsna;
     void *LAPACKE_ctrsna_work;
     void *LAPACKE_ctrsyl;
+    void *LAPACKE_ctrsyl3_work;
     void *LAPACKE_ctrsyl_work;
     void *LAPACKE_ctrtri;
     void *LAPACKE_ctrtri_work;
@@ -630,6 +635,8 @@ typedef struct _flexiblas_lapacke_backend {
     void *LAPACKE_cungrq_work;
     void *LAPACKE_cungtr;
     void *LAPACKE_cungtr_work;
+    void *LAPACKE_cungtsqr_row;
+    void *LAPACKE_cungtsqr_row_work;
     void *LAPACKE_cunmbr;
     void *LAPACKE_cunmbr_work;
     void *LAPACKE_cunmhr;
@@ -772,6 +779,8 @@ typedef struct _flexiblas_lapacke_backend {
     void *LAPACKE_dgetrs_work;
     void *LAPACKE_dgetsls;
     void *LAPACKE_dgetsls_work;
+    void *LAPACKE_dgetsqrhrt;
+    void *LAPACKE_dgetsqrhrt_work;
     void *LAPACKE_dggbak;
     void *LAPACKE_dggbak_work;
     void *LAPACKE_dggbal;
@@ -834,6 +843,8 @@ typedef struct _flexiblas_lapacke_backend {
     void *LAPACKE_dlag2s_work;
     void *LAPACKE_dlamch;
     void *LAPACKE_dlamch_work;
+    void *LAPACKE_dlangb;
+    void *LAPACKE_dlangb_work;
     void *LAPACKE_dlange;
     void *LAPACKE_dlange_work;
     void *LAPACKE_dlansy;
@@ -898,6 +909,8 @@ typedef struct _flexiblas_lapacke_backend {
     void *LAPACKE_dorgrq_work;
     void *LAPACKE_dorgtr;
     void *LAPACKE_dorgtr_work;
+    void *LAPACKE_dorgtsqr_row;
+    void *LAPACKE_dorgtsqr_row_work;
     void *LAPACKE_dormbr;
     void *LAPACKE_dormbr_work;
     void *LAPACKE_dormhr;
@@ -1209,6 +1222,8 @@ typedef struct _flexiblas_lapacke_backend {
     void *LAPACKE_dtrsna;
     void *LAPACKE_dtrsna_work;
     void *LAPACKE_dtrsyl;
+    void *LAPACKE_dtrsyl3;
+    void *LAPACKE_dtrsyl3_work;
     void *LAPACKE_dtrsyl_work;
     void *LAPACKE_dtrtri;
     void *LAPACKE_dtrtri_work;
@@ -1345,6 +1360,8 @@ typedef struct _flexiblas_lapacke_backend {
     void *LAPACKE_sgetrs_work;
     void *LAPACKE_sgetsls;
     void *LAPACKE_sgetsls_work;
+    void *LAPACKE_sgetsqrhrt;
+    void *LAPACKE_sgetsqrhrt_work;
     void *LAPACKE_sggbak;
     void *LAPACKE_sggbak_work;
     void *LAPACKE_sggbal;
@@ -1407,6 +1424,8 @@ typedef struct _flexiblas_lapacke_backend {
     void *LAPACKE_slag2d_work;
     void *LAPACKE_slamch;
     void *LAPACKE_slamch_work;
+    void *LAPACKE_slangb;
+    void *LAPACKE_slangb_work;
     void *LAPACKE_slange;
     void *LAPACKE_slange_work;
     void *LAPACKE_slansy;
@@ -1471,6 +1490,8 @@ typedef struct _flexiblas_lapacke_backend {
     void *LAPACKE_sorgrq_work;
     void *LAPACKE_sorgtr;
     void *LAPACKE_sorgtr_work;
+    void *LAPACKE_sorgtsqr_row;
+    void *LAPACKE_sorgtsqr_row_work;
     void *LAPACKE_sormbr;
     void *LAPACKE_sormbr_work;
     void *LAPACKE_sormhr;
@@ -1778,6 +1799,8 @@ typedef struct _flexiblas_lapacke_backend {
     void *LAPACKE_strsna;
     void *LAPACKE_strsna_work;
     void *LAPACKE_strsyl;
+    void *LAPACKE_strsyl3;
+    void *LAPACKE_strsyl3_work;
     void *LAPACKE_strsyl_work;
     void *LAPACKE_strtri;
     void *LAPACKE_strtri_work;
@@ -1909,6 +1932,8 @@ typedef struct _flexiblas_lapacke_backend {
     void *LAPACKE_zgetrs_work;
     void *LAPACKE_zgetsls;
     void *LAPACKE_zgetsls_work;
+    void *LAPACKE_zgetsqrhrt;
+    void *LAPACKE_zgetsqrhrt_work;
     void *LAPACKE_zggbak;
     void *LAPACKE_zggbak_work;
     void *LAPACKE_zggbal;
@@ -2107,6 +2132,8 @@ typedef struct _flexiblas_lapacke_backend {
     void *LAPACKE_zlacrm_work;
     void *LAPACKE_zlag2c;
     void *LAPACKE_zlag2c_work;
+    void *LAPACKE_zlangb;
+    void *LAPACKE_zlangb_work;
     void *LAPACKE_zlange;
     void *LAPACKE_zlange_work;
     void *LAPACKE_zlanhe;
@@ -2354,6 +2381,8 @@ typedef struct _flexiblas_lapacke_backend {
     void *LAPACKE_ztrsna;
     void *LAPACKE_ztrsna_work;
     void *LAPACKE_ztrsyl;
+    void *LAPACKE_ztrsyl3;
+    void *LAPACKE_ztrsyl3_work;
     void *LAPACKE_ztrsyl_work;
     void *LAPACKE_ztrtri;
     void *LAPACKE_ztrtri_work;
@@ -2385,6 +2414,8 @@ typedef struct _flexiblas_lapacke_backend {
     void *LAPACKE_zungrq_work;
     void *LAPACKE_zungtr;
     void *LAPACKE_zungtr_work;
+    void *LAPACKE_zungtsqr_row;
+    void *LAPACKE_zungtsqr_row_work;
     void *LAPACKE_zunmbr;
     void *LAPACKE_zunmbr_work;
     void *LAPACKE_zunmhr;
